<%!
// This method queries the CMS for a list of available groups and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available groups.

public String getAvailableGroups(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject group = null;

    try{

    // Query for all user group objects, which have the
    // ProgID "CrystalEnterprise.UserGroup".
    IInfoObjects groups = infoStore.query("Select SI_ID, SI_NAME From "
                 + "CI_SYSTEMOBJECTS Where SI_PROGID='CrystalEnterprise.UserGroup'");

    if (groups.size() == 0)
    {
        // The query returned a blank collection (no objects found).
        HTMLString = "<option value='0' disabled>No available groups.";
    }
    else
    {
        // Retrieve all of the user groups that were returned by the
        // query.
        for (int i = 0; i < groups.size(); i++)
        {
            group = (IInfoObject) groups.get(i);
	        HTMLString = HTMLString + "<option value='" + group.getID()
                                    + "'>" + group.getTitle();
	    }
    }
    return HTMLString;
    }	catch (SDKException e) {
          throw new Error ("Failed to retrieve the groups. Exception caught: "
                                   + e.getMessage());
    }
}

// This method queries the CMS for a list of available corporate categories and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available corporate categories.
public String getCorporateCategories(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject category = null;

    try
    {
        // Query for all corporate categories, which have the
        // SI_KIND "Category".
	    IInfoObjects categories = infoStore.query("Select SI_NAME, SI_ID From "
                     + "CI_INFOOBJECTS Where SI_KIND='Category'");

        if (categories.size() == 0)
        {
            // The query returned a blank collection (no objects found).
            HTMLString = "<option value='0' disabled>No categories found.";
        }
        else
        {
            // Retrieve all of the object packages that were returned by the
            // query.
            for (int i = 0; i < categories.size(); i++)
            {
                category = (IInfoObject) categories.get(i);
	            HTMLString = HTMLString + "<option value='" + category.getID()
                                    + "'>" + category.getTitle();
	        }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the categories. Exception caught: "
                         + e.getMessage());
    }
    
    return HTMLString;
}

// This method queries the CMS for a list of available personal categories and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available personal categories.
public String getPersonalCategories(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject category = null;

    try
    {
        // Query for all personal categories, which have the
        // SI_KIND "PersonalCategory".
	    IInfoObjects categories = infoStore.query("Select SI_NAME, SI_ID From "
                     + "CI_INFOOBJECTS Where SI_KIND='PersonalCategory'");

        if (categories.size() == 0)
        {
            // The query returned a blank collection (no objects found).
            HTMLString = "<option value='0' disabled>No categories found.";
        }
        else
        {
            // Retrieve all of the object packages that were returned by the
            // query.
            for (int i = 0; i < categories.size(); i++)
            {
                category = (IInfoObject) categories.get(i);
	            HTMLString = HTMLString + "<option value='" + category.getID()
                                    + "'>" + category.getTitle();
	        }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the categories. Exception caught: "
                         + e.getMessage());
    }
    
    return HTMLString;
}


// This method queries the CMS for a list of available object packages and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available object packages.
public String getObjectPackages(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject objPackage = null;

    try
    {
        // Query for all ObjectPackage objects, which have the
        // ProgID "CrystalEnterprise.ObjectPackage".
	    IInfoObjects packages = infoStore.query("Select SI_NAME, SI_ID From "
                     + "CI_INFOOBJECTS Where SI_PROGID = 'CrystalEnterprise.ObjectPackage' And SI_INSTANCE=0");

        if (packages.size() == 0)
        {
            // The query returned a blank collection (no objects found).
            HTMLString = "<option value='0' disabled>No object packages found.";
        }
        else
        {
            // Retrieve all of the object packages that were returned by the
            // query.
            for (int i = 0; i < packages.size(); i++)
            {
                objPackage = (IInfoObject) packages.get(i);
	            HTMLString = HTMLString + "<option value='" + objPackage.getID()
                                    + "'>" + objPackage.getTitle();
	        }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the object packages. Exception caught: "
                         + e.getMessage());
    }
    
    return HTMLString;
}

// This method queries the CMS for a list of available components and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available components.
public String getComponents(IInfoStore infoStore, String objPackageID)
{
	String HTMLString = "";
	IInfoObject objPackage = null;
	IInfoObject component = null;
	
    try
    {
	    IInfoObjects packages = infoStore.query("Select SI_CUID From "
	    		+ "CI_INFOOBJECTS Where SI_ID=" + objPackageID + " And SI_INSTANCE=0");
	    
	    if (packages.size() == 0)
        {
            // The query did not find the object package - throw an error
            throw new Error ("Object package not found.");
        }
        else
        {
	        objPackage = (IInfoObject) packages.get(0);
	        
	        // Use the CUID of the object package found above to find its components
	        IInfoObjects components = infoStore.query("Select SI_ID, SI_NAME "
	        	+ "From CI_INFOOBJECTS Where SI_PARENT_CUID='" + objPackage.getCUID() + "' And SI_INSTANCE = 0");
	        
	        if (components.size() == 0)
            {
                HTMLString = "<option value='0' disabled>No components found.";
            }
            else
            {
                // Retrieve all of the components that were returned by the
                // query.
                for (int i = 0; i < components.size(); i++)
                {
                    component = (IInfoObject) components.get(i);
	                HTMLString = HTMLString + "<option value='" + component.getID()
                                    + "'>" + component.getTitle();
	            }
            }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the components. Exception caught: "
                         + e.getMessage());
    }
    
    return HTMLString;
}            

// This method queries the CMS for a list of available calendars and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available calendars.
public String getCalendars(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject calendar = null;

    try
    {
        // Query for all Folder objects, which have the
        // ProgID "CrystalEnterprise.Folder".
	    IInfoObjects calendars = infoStore.query("Select SI_NAME, SI_ID From "
                     + "CI_SYSTEMOBJECTS Where SI_PROGID = 'CrystalEnterprise.Calendar' And SI_INSTANCE=0");

        if (calendars.size() == 0)
        {
            // The query returned a blank collection (no objects found).
            HTMLString = "<option value='0' disabled>No calendars found.";
        }
        else
        {
            // Retrieve all of the folders that were returned by the
            // query.
            for (int i = 0; i < calendars.size(); i++)
            {
                calendar = (IInfoObject) calendars.get(i);
	            HTMLString = HTMLString + "<option value='" + calendar.getID()
                                    + "'>" + calendar.getTitle();
	        }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the calendars. Exception caught: "
                         + e.getMessage());
    }
    
    return HTMLString;
}        
    
    
// This method queries the CMS for a list of available folders and prints
// them out as HTML option tags for the user to select.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies the list of available folders.

public String getAvailableFolders(IInfoStore infoStore)
    {
    String HTMLString = "";
    IInfoObject folder = null;

    try{

    // Query for all Folder objects, which have the
    // ProgID "CrystalEnterprise.Folder".
	IInfoObjects folders = infoStore.query("Select SI_NAME, SI_ID From "
                 + "CI_INFOOBJECTS Where SI_PROGID = 'CrystalEnterprise.Folder'");

    if (folders.size() == 0)
        {
        // The query returned a blank collection (no objects found).
        HTMLString = "<option value='0' disabled>No available folders.";
        }
    else
        {
        // Retrieve all of the folders that were returned by the
        // query.
        for (int i = 0; i < folders.size(); i++)
            {
            folder = (IInfoObject) folders.get(i);
	        HTMLString = HTMLString + "<option value='" + folder.getID()
                                    + "'>" + folder.getTitle();
	        }
        }
    }catch (SDKException e) {
          throw new Error ("Failed to retrieve the folders. Exception caught: "
                                   + e.getMessage());
    }
    return HTMLString;
    }

// This method gets the member groups that a user belongs to and returns
// them as HTML option tags.
//
// Parameters:
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
// userID [In]
//     An string that specifies the ID of the user.
//
// Returns: A String that specifies the user's member groups.

public String getMemberGroups(IInfoStore infoStore, String userID)
    {
    String HTMLString = "";

    try{

    // Query for the user object with the specified userID.
	IInfoObjects users = infoStore.query("Select TOP 1* From CI_SYSTEMOBJECTS "
                                            + "Where SI_ID=" + userID);
	if (users.size() == 0)
	    {
	    // The query returned a blank collection (no object found).
        HTMLString = "<option value='0' disabled>The user account does not exist";
        }
    else
        {
        // Retrieve the object from the collection.
	    IInfoObject user = (IInfoObject) users.get(0);

	    // Check that the object has the correct ProgID.
        String uProgID = (String) user.properties().getProperty(CePropertyID.SI_PROGID).getValue();
        if (uProgID.equals(CeProgID.USER))
            {
            // Obtain the set of groups which the user belongs to.
       	    Object[] memberGroups = ((IUser)user).getGroups().toArray();

            for (int i = 0; i < memberGroups.length; i++)
	            {
	            // Retrieve each group from the infoStore.
         	    IInfoObjects result = infoStore.query ("SELECT SI_NAME FROM "
                             + "CI_SYSTEMOBJECTS WHERE SI_ID=" + memberGroups[i]);
		        IInfoObject iObject = (IInfoObject) result.get(0);
		        HTMLString = HTMLString + "<option value='" + iObject.getID()
                                        + "'>" + iObject.getTitle();
		        }
            }
        else
            {
            HTMLString = "<option value='0' disabled>No groups available";
            }
        }
    }catch (SDKException e) {
          throw new Error ("Failed to retrieve the groups. Exception caught: "
                                   + e.getMessage());
    }
    return HTMLString;
    }

// This method gets a list all available reports in the form of
// HTML option tags.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies all the available reports.

public String getReports(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject report = null;

    try
    {
        // Query for all report objects that are not instances.
        IInfoObjects reports = infoStore.query("Select SI_ID, SI_NAME From "
                             + "CI_INFOOBJECTS Where SI_PROGID='CrystalEnterprise.Report' "
                             + "And SI_INSTANCE=0");

	    if (reports.size() == 0)
	    {
	        // The query returned a blank collection (no object found).
            HTMLString = "<option value='0' disabled>No available reports.";
        }
        else
        {
            // Retrieve each report from the collection and build the drop
            // down box. Set the report's ID as the value for the option element.
            // This will garauntee its uniqueness.
	        for (int i = 0; i < reports.size(); i++)
	        {
                report = (IInfoObject) reports.get(i);
	            HTMLString = HTMLString + "<option value='" + report.getID()
                                        + "'>" + report.getTitle();
		    }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the reports. Exception caught: "
                                   + e.getMessage());
    }
    
   	return HTMLString;
}

// This method gets a list all available Webi reports in the form of
// HTML option tags.
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies all the available Webi reports.

public String getWebiReports(IInfoStore infoStore)
{
    String HTMLString = "";
    IInfoObject webiReport = null;

    try
    {
        // Query for all Webi report objects that are not instances.
        IInfoObjects webiReports = infoStore.query("Select SI_ID, SI_NAME From "
                                + "CI_INFOOBJECTS Where SI_PROGID='CrystalEnterprise.Webi' "
                                + "And SI_INSTANCE=0");

	    if (webiReports.size() == 0)
	    {
	        // The query returned a blank collection (no object found).
            HTMLString = "<option value='0' disabled>No available reports.";
        }
        else
        {
            // Retrieve each Webi report from the collection and build the drop
            // down box. Set the report's ID as the value for the option element.
            // This will garauntee its uniqueness.
	        for (int i = 0; i < webiReports.size(); i++)
	        {
                webiReport = (IInfoObject) webiReports.get(i);
	            HTMLString = HTMLString + "<option value='" + webiReport.getID()
                                        + "'>" + webiReport.getTitle();
		    }
        }
    }
    catch (SDKException e)
    {
        throw new Error ("Failed to retrieve the Webi reports. Exception caught: "
                                   + e.getMessage());
    }
    
   	return HTMLString;
}

// This method gets a list of all the servers connected to the CMS
// (including all CMS's) in the form of HTML option tags.
//
// Parameters:
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies all the servers.

public String getServers(IInfoStore infoStore)
    {
    String HTMLString = "";
    IInfoObject server = null;

    try{
    // Query for all server objects, which have the
    // ProgID "CrystalEnterprise.Server".

	//_BEGINSNIPPET_:Codeblock_getAllServersJAVA.txt
    IInfoObjects servers = infoStore.query("Select SI_ID, SI_FRIENDLY_NAME"
                           + " From CI_SYSTEMOBJECTS"
                           + " Where SI_PROGID='CrystalEnterprise.Server'");

    if (servers.size() == 0)
        {
        // The query returned a blank collection (no object found).
        HTMLString = "<option value='0' disabled>No servers or CMS found";
        }

    // Retrieve each server from the collection and build the drop
    // down box. Set the server's ID as the value for the option element.
    // This will garauntee its uniqueness.
    for (int i = 0; i < servers.size(); i++)
        {
        server = (IInfoObject) servers.get(i);
	    HTMLString = HTMLString + "<option value='" + server.getID()
                                + "'>" + server.getTitle();
	    }
	//_ENDSNIPPET_

    }catch (SDKException e) {
          throw new Error ("Failed to retrieve the servers. Exception caught: "
                                   + e.getMessage());
    }
    return HTMLString;
    }

// This method gets a list of all server groups on the CMS in the form of
// HTML option tags.
//
// Parameters:
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies all the CMS server groups.

public String getServerGroups(IInfoStore infoStore)
    {
	// Query for all server groups.
	String HTMLString = "";
	IInfoObject serverGroup = null;

    try{
    // Query for all server group objects, which have the
    // ProgID "CrystalEnterprise.ServerGroup".


	IInfoObjects serverGroups = infoStore.query("Select SI_SERVER_GROUP, "
                              + "SI_ID, SI_NAME From CI_SYSTEMOBJECTS "
                              + "Where SI_PROGID='CrystalEnterprise.ServerGroup'");

	if (serverGroups.size() == 0)
		{
		// The query returned a blank collection (no object found).
		HTMLString = "<option value='0' disabled>No server groups found";
		}
	else
		{
	    // Retrieve each server group from the collection and build the
        // drop down box. Set the server group's ID as the value for the
        // option element. This will garauntee its uniqueness._
		for (int i = 0; i < serverGroups.size(); i++)
		    {
            serverGroup = (IInfoObject) serverGroups.get(i);
	        HTMLString = HTMLString + "<option value='" + serverGroup.getID()
                                    + "'>" + serverGroup.getTitle();
			}
        }


	}catch (SDKException e) {
          throw new Error ("Failed to retrieve the server groups. Exception caught: "
                                   + e.getMessage());
    }
	return HTMLString;
    }

// This method gets all user accounts and prints them out as HTML option tags.
//
// Parameters:
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
//
// Returns: A String that specifies all user accounts.

public String getUsers(IInfoStore infoStore)
    {
	String HTMLString = "";
	IInfoObject user = null;

    try{
    // Query for all server group objects, which have the
    // ProgID "CrystalEnterprise.User".
	IInfoObjects users = infoStore.query("Select SI_ID, SI_NAME From "
                 + "CI_SYSTEMOBJECTS Where SI_PROGID='CrystalEnterprise.USER'");

	if (users.size() == 0)
	    {
	    // The query returned a blank collection (no object found).
		HTMLString = "<option value='0' disabled>No user accounts found";
		}
	else
		{
	    // Retrieve each server group from the collection and build the
        // drop down box. Set the server group's ID as the value for the
        // option element. This will garauntee its uniqueness.ENDLOC_
        for (int i = 0; i < users.size(); i++)
            {
            user = (IInfoObject) users.get(i);
	        HTMLString = HTMLString + "<option value='" + user.getID()
                                    + "'>" + user.getTitle();
		    }
		}
    }catch (SDKException e) {
          throw new Error ("Failed to retrieve the users. Exception caught: "
                                   + e.getMessage());
    }
	return HTMLString;
    }

// This method adds a group to the CMS with a name and description specified
// by the user. Used in ModifyUserGroups.jsp & ModifyGroupMembership.jsp.
//
// Parameters:
//
// infoStore [In]
//     An InfoStore object that accesses BusinessObjects Enterprise objects.
// name [In]
//     A String that specifies the name of the group the user wishes to add.
// description [In]
//     A String that specifies the description of the group the user wishes
//     to add.
// Returns: An int that specifies the ID of the new user group.

int addUserGroup(IInfoStore infoStore, String name, String description)
    {
    int objectID = 0;

    try{

	//_BEGINSNIPPET_:Codeblock_addUserGroupJAVA.txt
    // Use the plugin manager and the UserGroup plugin to create a new
    // UserGroup object.
    IPluginMgr pluginMgr = infoStore.getPluginMgr();
    IPluginInfo userGroupPlugin = pluginMgr.getPluginInfo("CrystalEnterprise.UserGroup");

    // Create a new InfoObjects collection.
    IInfoObjects newInfoObjects = infoStore.newInfoObjectCollection();

    // Add the UserGroup interface to the new InfoObjects collection.
    newInfoObjects.add(userGroupPlugin);

    // Get the new UserGroup object from the collection.
   	IInfoObject iObject = (IInfoObject) newInfoObjects.get(0);

    // Once you have the new UserGroup object, set its properties.
    iObject.setTitle (name);
    iObject.setDescription (description);

    // Retrieve the ID of the InfoObject (user group).
    objectID = iObject.getID();

    // Save the new group to the CMS.
    infoStore.commit (newInfoObjects);
	//_ENDSNIPPET_

	}catch (SDKException e) {
          throw new Error ("Failed to add the user group. Exception caught: "
                                   + e.getMessage());
    }
    return objectID;
    }
%>